==> pencil2d_0.6.1.orig.tar.gz: pencil-0.6.1/README.md <==

[![Build Status](https://travis-ci.org/pencil2d/pencil.svg?branch=master)](https://travis-ci.org/pencil2d/pencil)
[![Build status](https://ci.appveyor.com/api/projects/status/65p3ccmohnkmim4x?svg=true)](https://ci.appveyor.com/project/chchwy/pencil2d)

# Pencil2D Animation

**Pencil2D** is an animation/drawing software for Mac OS X, Windows, and Linux. It lets you create traditional hand-drawn animation (cartoon) using both bitmap and vector graphics. Pencil2D is free and open source.

## Download ###

### Pencil2D 0.6  (1 December 2017)

[What's new?](https://www.pencil2d.org/2017/12/introducing-pencil2d-0.6.html)

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][0]    | [Download][1]     | [Download][2]   | [Download][3]     |

[0]: https://github.com/pencil2d/pencil/releases/download/0.6.0/pencil2d-win64-0.6.0-ffmpeg341.zip
[1]: https://github.com/pencil2d/pencil/releases/download/0.6.0/pencil2d-win32-0.6.0.zip
[2]: https://github.com/pencil2d/pencil/releases/download/0.6.0/pencil2d-mac-0.6.0.zip
[3]: https://github.com/pencil2d/pencil/releases/download/0.6.0/pencil2d-linux-amd64-0.6.0.AppImage

### Debian & Ubuntu

```bash    
sudo apt-get install pencil2d
```

### Homebrew Cask (macOS)

```bash
brew cask install pencil2d
```

### Nightly build

Nightly builds are the bleeding edge versions of Pencil2D, which contains the most recent fixes and features.
The link will direct you to Google Drive, please right-click a file and select Download. The filename is pencil2d-OS-year-month-date.

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][4]    | [Download][5]     | [Download][6]   | [Download][7]     |

[4]: https://goo.gl/ZaYAtw
[5]: https://goo.gl/cKbtgM
[6]: https://goo.gl/WrAVu9
[7]: https://goo.gl/9TzYRV

## Links

* Pencil2D Official Website: <https://www.pencil2d.org/>
* Report a bug or Request features in [Issue tracker](https://github.com/pencil2d/pencil/issues)
* You can help translate Pencil2D on [transifex](https://www.transifex.com/pencil2d/)!
* [Developer Guide](https://github.com/pencil2d/pencil/wiki)

## Source code

* Github: [https://github.com/pencil2d/pencil](https://github.com/pencil2d/pencil)
* Bitbucket: [https://bitbucket.org/chchwy/pencil2d](https://bitbucket.org/chchwy/pencil2d) (Mirror)

==> pencil2d_0.6.1.1.orig.tar.gz: pencil-0.6.1.1/README.md <==

[![Build Status](https://travis-ci.org/pencil2d/pencil.svg?branch=master)](https://travis-ci.org/pencil2d/pencil)
[![Build status](https://ci.appveyor.com/api/projects/status/65p3ccmohnkmim4x?svg=true)](https://ci.appveyor.com/project/chchwy/pencil2d)

# Pencil2D Animation

**Pencil2D** is an animation/drawing software for Mac OS X, Windows, and Linux. It lets you create traditional hand-drawn animation (cartoon) using both bitmap and vector graphics. Pencil2D is free and open source.

## Download ###

### Pencil2D 0.6.1  (15 April 2018)

[What's new?](https://www.pencil2d.org/2017/12/introducing-pencil2d-0.6.html)

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][0]    | [Download][1]     | [Download][2]   | [Download][3]     |

[0]: https://github.com/pencil2d/pencil/releases/download/v0.6.1/pencil2d-win64-0.6.1.zip
[1]: https://github.com/pencil2d/pencil/releases/download/v0.6.1/pencil2d-win32-0.6.1.zip
[2]: https://github.com/pencil2d/pencil/releases/download/v0.6.1/pencil2d-mac-0.6.1.zip
[3]: https://github.com/pencil2d/pencil/releases/download/v0.6.1/pencil2d-linux-amd64-0.6.1.AppImage

### Debian & Ubuntu

```bash    
sudo apt-get install pencil2d
```

### Homebrew Cask (macOS)

```bash
brew cask install pencil2d
```

### Nightly build

Nightly builds are the bleeding edge versions of Pencil2D, which contains the most recent fixes and features.
The link will direct you to Google Drive, please right-click a file and select Download. The filename is pencil2d-OS-year-month-date.

| Windows 64 bit   | Windows 32 bit    | Mac             | Linux             |
| :--------------: | :---------------: | :-------------: | :---------------: |
| [Download][4]    | [Download][5]     | [Download][6]   | [Download][7]     |

[4]: https://goo.gl/ZaYAtw
[5]: https://goo.gl/cKbtgM
[6]: https://goo.gl/WrAVu9
[7]: https://goo.gl/9TzYRV

## Links

* Pencil2D Official Website: <https://www.pencil2d.org/>
* Report a bug or Request features in [Issue tracker](https://github.com/pencil2d/pencil/issues)
* You can help translate Pencil2D on [transifex](https://www.transifex.com/pencil2d/)!
* [Developer Guide](https://github.com/pencil2d/pencil/wiki)

## Source code

* Github: [https://github.com/pencil2d/pencil](https://github.com/pencil2d/pencil)
* Bitbucket: [https://bitbucket.org/chchwy/pencil2d](https://bitbucket.org/chchwy/pencil2d) (Mirror)
